EDuke32 Changelog Unofficial archive

What changed in EDuke32, build by build

2,117 builds · 8,866 commits · 25 authors · October 2009 – August 2026

Commits per year

Showing 2012 · select it again to see every year
SVN era · r1519 – r8798 Git era · voidpoint.io, from april 2020
Filters · 3 active

Showing 1 build · 4 commits

Export CSV
Display options
Commit details:

July 2012 1 build · 4 commits

Build 2834

13 Jul 2012 · 9 commits · 1 author SVN
Open build
  • VP8

    clamp GL texture to edge if possible, preventing potential stray lines

    Helixhorned r2834 13 Jul, 11:21
  • VP8

    don't call I_ClearAllInput() before idle loop.

    Helixhorned r2833 13 Jul, 11:20
    Show details

    If input is cleared before, it can become impossible to cancel the video when decoding and displaying a frame takes longer than a frame.

  • VP8

    collect times while playing the video and print a summary to the log afterwards.

    Helixhorned r2832 13 Jul, 11:20
  • VP8

    unroll 3 planes -> packed conversion loop.

    Helixhorned r2830 13 Jul, 11:20
    Show details

    On an AMD Phenom II X4 system with generic memory modules, this brings down the mean time for this conversion from 16.5 to 10.5 ms. (GCC 4.6.1, optimized build)

Open the build to see all 9 commits